@@ -1,4 +1,4 @@
-from .cli import cli
+from .cli.core import cli
 
 # Make the CLI available as `python -m plain`
 if __name__ == "__main__":
