@@ -1,23 +1,27 @@
+from __future__ import annotations
+
+from typing import Any
+
 from plain.packages import packages_registry
 
 
 class CLIRegistry:
     def __init__(self):
-        self._commands = {}
+        self._commands: dict[str, Any] = {}
 
-    def register_command(self, cmd, name):
+    def register_command(self, cmd: Any, name: str) -> None:
         """
         Register a CLI command or group with the specified name.
         """
         self._commands[name] = cmd
 
-    def import_modules(self):
+    def import_modules(self) -> None:
         """
         Import modules from installed packages and app to trigger registration.
         """
         packages_registry.autodiscover_modules("cli", include_app=True)
 
-    def get_commands(self):
+    def get_commands(self) -> dict[str, Any]:
         """
         Get all registered commands.
         """
@@ -27,7 +31,7 @@ class CLIRegistry:
 cli_registry = CLIRegistry()
 
 
-def register_cli(name):
+def register_cli(name: str) -> Any:
     """
     Register a CLI command or group with the given name.
 
@@ -38,7 +42,7 @@ def register_cli(name):
             pass
     """
 
-    def wrapper(cmd):
+    def wrapper(cmd: Any) -> Any:
         cli_registry.register_command(cmd, name)
         return cmd
 
