@@ -2,7 +2,7 @@ from plain.exceptions import ValidationError
 
 
 class FormFieldMissingError(Exception):
-    def __init__(self, field_name):
+    def __init__(self, field_name: str):
         self.field_name = field_name
         self.message = f'The "{self.field_name}" field is missing from the form data.'
 
