@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import logging
 from functools import wraps
+from typing import TYPE_CHECKING
 
 from plain import signals
 from plain.exceptions import (
@@ -12,13 +15,20 @@ from plain.exceptions import (
 )
 from plain.http import Http404, ResponseServerError
 from plain.http.multipartparser import MultiPartParserError
-from plain.logs import log_response
+from plain.logs.utils import log_response
 from plain.runtime import settings
 from plain.utils.module_loading import import_string
 from plain.views.errors import ErrorView
 
+if TYPE_CHECKING:
+    from collections.abc import Callable
 
-def convert_exception_to_response(get_response):
+    from plain.http import Request, Response
+
+
+def convert_exception_to_response(
+    get_response: Callable[[Request], Response],
+) -> Callable[[Request], Response]:
     """
     Wrap the given get_response callable in exception-to-response conversion.
 
@@ -33,7 +43,7 @@ def convert_exception_to_response(get_response):
     """
 
     @wraps(get_response)
-    def inner(request):
+    def inner(request: Request) -> Response:
         try:
             response = get_response(request)
         except Exception as exc:
@@ -43,7 +53,7 @@ def convert_exception_to_response(get_response):
     return inner
 
 
-def response_for_exception(request, exc):
+def response_for_exception(request: Request, exc: Exception) -> Response:
     if isinstance(exc, Http404):
         response = get_exception_response(
             request=request, status_code=404, exception=None
@@ -120,7 +130,9 @@ def response_for_exception(request, exc):
     return response
 
 
-def get_exception_response(*, request, status_code, exception):
+def get_exception_response(
+    *, request: Request, status_code: int, exception: Exception | None
+) -> Response:
     try:
         view_class = get_error_view(status_code=status_code, exception=exception)
         return view_class(request)
@@ -135,7 +147,9 @@ def get_exception_response(*, request, status_code, exception):
         return ResponseServerError()
 
 
-def get_error_view(*, status_code, exception):
+def get_error_view(
+    *, status_code: int, exception: Exception | None
+) -> Callable[[Request], Response]:
     views_by_status = settings.HTTP_ERROR_VIEWS
     if status_code in views_by_status:
         view = views_by_status[status_code]
